@@ -11,12 +11,18 @@
 //! by building with `default_features = false` (by default, the `"async"`
 //! feature is enabled).
 
-// XXX this is broken with ale
-// #![warn(clippy::cargo)]
+#![warn(clippy::cargo)]
 #![warn(clippy::pedantic)]
 #![warn(clippy::nursery)]
+#![warn(clippy::as_conversions)]
+#![warn(clippy::get_unwrap)]
+#![allow(clippy::cognitive_complexity)]
 #![allow(clippy::missing_const_for_fn)]
-#![allow(clippy::multiple_crate_versions)]
+#![allow(clippy::similar_names)]
+#![allow(clippy::struct_excessive_bools)]
+#![allow(clippy::too_many_arguments)]
+#![allow(clippy::too_many_lines)]
+#![allow(clippy::type_complexity)]
 
 mod creator;
 pub use creator::Creator;
